@@ -99,17 +99,22 @@ def {f}(self, new_value):
         assert key in self._fields
         # if the supplied value is a filename we want
         # to use the contents of the file, not the filename itself
-        if key in self._media_fields and self._is_path(value):
-            if key in self._text_fields:
-                value = Path(value).read_text()
-            if key in self._BLOB_fields:
-                value = Path(value).read_bytes()
         self._dict[key] = value
         # commit change to card-dictionary to SQL database
         self._cursor.execute(f'UPDATE cards SET {key} = ? WHERE id = ?',
                              (value, self.id))
         self._cursor.connection.commit()
 
+    def set(self, key, value):
+        # user access to __setitem__ functionality
+        # if a filename is specified as the value read the contents of that file.
+        if key in self._media_fields and self._is_path(value):
+            if key in self._text_fields:
+                value = Path(value).read_text()
+            if key in self._BLOB_fields:
+                value = Path(value).read_bytes()
+        self.__setitem__(key, value)
+
     set = __setitem__  # alias for easy cli usage
     set.__doc__ = 'set the text or image for a card: `set front_image ./diagram.png`'
 
@@ -203,21 +208,19 @@ def {f}(self, new_value):
             return self._review_verses()
 
         with AlternateScreen():
-            ansi.light();
-            print(self.tags, '\n', sep='');
-            ansi.reset()
+            print('Recite the lines one by one. Press space to show the next line.')
+            print(f'[dim yellow italic]{" ".join(self.tags)}', '\n', sep='')
             lines = self.front_text.splitlines()
             print(f'[bold]{lines.pop(0)}')
             for line in lines:
                 char = readkey()  # press any key to continue
                 if char == 'e':
                     return edit_then_review()
-                if char in ['d', 'q']:  # exit actions to abort the review
+                if char in ['d', 'q', '\x1b']:  # exit actions to abort the review
                     return char
                 print(f'[bold]{line}')
 
             # grade the card
-            print('\n\n[END]')
             print('\n\n')
             print(help_string)
             grade = readkey()
@@ -356,5 +359,6 @@ def {f}(self, new_value):
     def _new_card(cls, cursor):
         cursor.execute("INSERT INTO cards DEFAULT VALUES")
         cursor.connection.commit()
-        id = cursor.execute("SELECT last_insert_rowid()").fetchone()[0]
+        id = cursor.execute("SELECT id FROM cards WHERE"
+                            " rowid = last_insert_rowid()").fetchone()[0]
         return cls(id, cursor)
