@@ -30,7 +30,7 @@ tutorial = _Cardlist(_tutorial_cursor)
 
 # import some methods of the collection Cardlist object directly into the module's namespace
 # this is so that ```vinca col review``` can be written as ```vinca review```
-_methods = ('browse', 'count', 'filter', 'find', 'findall', 'review', 'sort', 'time', 'purge', 'basic', 'verses', 'stats')
+_methods = ('browse', 'count', 'filter', 'find', 'findall', 'review', 'sort', 'purge', 'basic', 'verses', 'stats')
 for _method_name in _methods:
     globals()[_method_name] = getattr(collection, _method_name)
 
